@@ -12,9 +12,7 @@ class LocationError(Exception):
 
 def get(address: str) -> Location:
     address = urllib.parse.quote(address)
-    response = httpx.get(
-        f"https://nominatim.openstreetmap.org/search/{address}?format=json"
-    )
+    response = httpx.get(f"https://nominatim.openstreetmap.org/search/{address}?format=json")
 
     if not response.is_success:
         raise LocationError()
